@@ -4,11 +4,12 @@
 // Description: 
 //
 //
-// Author: %{AUTHOR} <%{EMAIL}>, (C) %{YEAR}
+// Author: Benjamin Mesing <bensmail@gmx.net>, (C) 2005
 //
 // Copyright: See COPYING file that comes with this distribution
 //
 //
+
 #ifndef __NPLUGIN_PACKAGENAMEPLUGIN_H_2005_03_13
 #define __NPLUGIN_PACKAGENAMEPLUGIN_H_2005_03_13
 
@@ -27,6 +28,7 @@ namespace NPlugin {
   */
 class PackageNamePlugin : public ShortInformationPlugin
 {
+Q_OBJECT
 	const QString _title;
 	const QString _briefDescription;
 	const QString _description;
@@ -58,7 +60,7 @@ public:
 	virtual uint shortInformationPriority() const	{ return 0; }
 	virtual const QString shortInformationText(const string& package);
 	/** @brief Returns <b>Name</b> */
-	virtual QString shortInformationCaption() const { return QString("Name"); };
+	virtual QString shortInformationCaption() const { return tr("Name"); };
 	// documented in base class
 	virtual int preferredColumnWidth() const { return 20; }
 	//@}
