@@ -37,11 +37,14 @@
 #include <QWhatsThis>
 #include <QtDebug>
 
+#include <xapian.h>
+
 #include <wibble/operators.h>
 
 #include <ept/apt/apt.h>
 #include <ept/debtags/debtags.h>
-#include <ept/textsearch/textsearch.h>
+#include <ept/debtags/vocabulary.h>
+#include <ept/axi/axi.h>
 
 
 // NApplication
@@ -100,10 +103,9 @@ PackageSearchImpl::PackageSearchImpl( QWidget* parent, const char* name, Qt::WFl
 	setObjectName(name);
 	setupUi(this);
 
-	_pApt = new ept::apt::Apt;
-	_pDebtags = new ept::debtags::Debtags;
-	_pTextsearch = new ept::textsearch::TextSearch;
-
+	_pApt = 0;
+	_pVocabulary = 0;
+	_pXapianDatabase = 0;
 	// set up what's this actions
 	_pWhatsThisAction = QWhatsThis::createAction(this);
 	_pWhatsThisAction->setShortcut(QKeySequence("Shift+F1"));
@@ -116,7 +118,7 @@ PackageSearchImpl::PackageSearchImpl( QWidget* parent, const char* name, Qt::WFl
 	// delete placeholder ListViewWidget and replace by a custom class
 	delete _pPackageView;
 	_pPackageView = new NPackageSearch::PackageDisplayWidget(_pPackageViewFrame);
-	_pPackageView->setWhatsThis("Displays the packages matching the search entered above.");
+	_pPackageView->setWhatsThis(tr("Displays the packages matching the search entered above."));
  	_pPackageViewFrame->layout()->addWidget(_pPackageView);
 	
 	
@@ -171,8 +173,8 @@ PackageSearchImpl::~PackageSearchImpl()
 	delete _pPackageNamePlugin;
 	delete _pScoreDisplayPlugin;
 	delete _pApt;
-	delete _pDebtags;
-	delete _pTextsearch;
+	delete _pVocabulary;
+	delete _pXapianDatabase;
 }
 
 
@@ -243,6 +245,34 @@ void PackageSearchImpl::initMenus()
 
 void PackageSearchImpl::initialize()
 {
+
+	_pApt = new ept::apt::Apt;
+	_pVocabulary = new ept::debtags::Vocabulary;
+	// TODO: check if the database is up-to-date (though 
+	// apt-xapian-index by default updates the index after installation and weekly
+	bool success = false;
+	// try running until Xapian::Database can be constructed
+	do 
+	{
+		try {
+			_pXapianDatabase = new Xapian::Database(ept::axi::path_db());
+			success = true;
+		} catch (Xapian::RuntimeError& e) {
+			if ( QMessageBox::critical(this, tr("Error trying to open Xapian database"), 
+					tr("<p>An error occurred trying to open the xapian database at "
+						"/var/lib/apt-xapian-index/index please make sure the file is "
+						"readable and valid. You may try to run update-apt-xapian-index "
+						"to fix this problem. The orginal error message was:<br>\"") +
+					toQString(e.get_msg()) + "\"</p>" + 
+					tr("Would you like to run update-apt-xapian-index now? Otherwise "
+						"packagesearch will be terminated."), QMessageBox::Yes, QMessageBox::No) == QMessageBox::No )
+				exit(2);
+			updateXapianDatabase();
+		}
+	}
+	while (!success);
+
+
 	// create the hard coded plugins
 	_pPackageNamePlugin = new NPlugin::PackageNamePlugin();
 	this->addPlugin(_pPackageNamePlugin);
@@ -459,12 +489,8 @@ const set<string>& PackageSearchImpl::packages() const
 
 void PackageSearchImpl::reloadAptFrontCache()
 {
-// 	delete _pDebtags;
 	delete _pApt;
-	delete _pTextsearch;
-// 	_pDebtags = new ept::debtags::Debtags;
 	_pApt = new ept::apt::Apt;
-	_pTextsearch = new ept::textsearch::TextSearch;
 }
 
 /////////////////////////////////////////////////////
@@ -1023,5 +1049,21 @@ void PackageSearchImpl::setTranslationDir(const QDir& dir)
 }
 
 
-
+void PackageSearchImpl::updateXapianDatabase() 
+{
+	setEnabled(false);
+	NApplication::RunCommand* pCommand = NApplication::ApplicationFactory::getInstance()->getRunCommand("");
+	pCommand->addArgument("/usr/sbin/update-apt-xapian-index");
+	pCommand->addArgument("-f");
+	pCommand->startAsRoot();
+	while (!pCommand->finished()) 
+	{
+		pCommand->waitForFinished(500);
+ 		qApp->processEvents();
+	}
+	// reload new xapian database
+	delete _pXapianDatabase;
+	_pXapianDatabase = new Xapian::Database(ept::axi::path_db());
+	setEnabled(true);
+}
 
