@@ -17,8 +17,13 @@
 
 #include "installationtool.h"
 
+
+
+
 namespace NPlugin {
 
+class IAptMediator;
+
 /** @brief Plugin offerings actions realted to apt.
   *
   * The actions offered are:
@@ -38,28 +43,40 @@ Q_OBJECT
 	const QString _briefDescription;
 	const QString _description;
 	/** @brief Action used to update the apt database. */
-	Action* _pAptUpdateAction;
+	Action* _pUpdateAction;
 	/** @brief Action used to reload the apt database. */
 	Action* _pReloadDbAction;
-	Action* _pAptGetLineAction;
-	Action* _pAptGetInstallAction;
-	Action* _pAptGetRemoveAction;
+	Action* _pCreateInstallLineAction;
+	/** @name Package Actions
+	  * 
+	  * @brief Actions for installing/removing packages.
+	  */
+	//@{
+	Action* _pInstallAction;
+	Action* _pRemoveAction;
+	Action* _pPurgeAction;
+	//@}
 	Action* _pSeparatorAction;
 	IProvider* _pProvider;
-	/** Holds which tool to use for installing/removing packages. */
-	InstallationTool _installationTool;
-	/** Holds the path to the installation tool to be used. */
-	QString _installationToolPath;
+	IAptMediator* _pMediator;
 protected slots:
-	void onAptGetLineAction();
-	void onAptGetInstallAction();
-	void onAptGetRemoveAction();
+	void onCreateInstallLineAction();
+	void onInstallAction();
+	void onRemoveAction();
+	void onPurgeAction();
+	void onUpdateAction();
+	void onReloadAction();
 protected:
-	/** @brief Installs or removes the current package. */
-	void aptGetInstallOrRemove(bool install);
+	/** @brief Installs or removes the current package. 
+	  *
+	  * @param install if true, the package will be installed, if false it will be removed
+	  * @param purge determines if the package shall be purged on removal (no effect for
+	  * installing)
+	  */
+	void installOrRemove(bool install, bool purge = false);
 public:
 	static const QString PLUGIN_NAME;
-	AptActionPlugin();
+	AptActionPlugin(IAptMediator* pMediator);
 	~AptActionPlugin();
 	/** @name Plugin Interface
 	  * 
@@ -77,9 +94,9 @@ public:
 	virtual QString description() const { return _description; };
 	//@}
 	/** @brief Returns the QAction object for the #_pAptUpdateAction. */
-	QAction* qAptUpdateAction() const { return _pAptUpdateAction->action(); }
+	QAction* qAptUpdateAction() const { return _pUpdateAction->action(); }
 	/** @brief Returns the QAction object for the #_pReloadDbAction. */
-	QAction* qRealoadDbAction() const { return _pReloadDbAction->action(); }
+	QAction* qReloadDbAction() const { return _pReloadDbAction->action(); }
 
 	/** @name ActionPlugin Interface
 	  * 
@@ -89,8 +106,9 @@ public:
 	virtual vector<Action*> actions() const;
 	//@}
 	
-	InstallationTool installationTool();
-	void setInstallationTool(InstallationTool tool);
+private:
+	/** @brief Shortcut for calling _aptMediator->installationToolCommand() */
+	QString installationToolCommand();
 };
 
 }
