@@ -9,6 +9,9 @@
 
 #include "iaptmediator.h"
 
+#include "installationtool.h"
+
+
 class QAction;
 
 class ExtPackageDB;
@@ -25,6 +28,8 @@ namespace NApt
 	class DumpAvailPackageDB;
 }
 
+class AptSettingsWidget;
+
 namespace NPlugin
 {
 
@@ -56,6 +61,13 @@ class AptPluginContainer : public QObject, public BasePluginContainer, public IA
 	  * and for searching. 
 	  */
 	NApt::AptFrontPackageDB* _pAptFrontPackageDB; 
+	/** @brief This holds a pointer to the settings widget currently active.
+	  * 
+	  * This pointer must not be deleted and should only be used in applySettings(). 
+	  */
+	AptSettingsWidget* _pSettingsWidget;
+	/** @brief Holds the installation tool to be used for installation (APT). */
+	NApt::InstallationTool _installationTool;
 public:
 	/**
 	  * Default Constructor
@@ -83,14 +95,32 @@ public:
 	/** @returns "aptplugin" */
 	virtual string name() const {	return "aptplugin"; };
 	virtual QString title() const	{ return QString("Apt Plugins"); };
+	virtual QWidget* getSettingsWidget(QWidget* pParent);
+	virtual void applySettings();
 	//@}
+	
+	/** @name BasePluginContainer Overloads
+	  *
+	  * These functions implement saving and loading of the container settings
+	  * as described in BasePluginContainer.
+	  */
+	//@{
+	virtual QDomElement loadContainerSettings(const QDomElement source);
+	virtual void saveContainerSettings(NXml::XmlData& outData, QDomElement parent) const;
+	//@}
+	
+	/** @name IAptMediator Overloads
+	  *
+	  */
 	// documened in base class
+	//@{
+	virtual void setInstallationTool(NApt::InstallationTool tool);
+	virtual QString installationToolCommand();
 	virtual QStringList searchPatterns();
+	virtual void updateAptDatabase();
+	virtual void reloadAptDatabase();
+	//@}
 protected slots:
-	/** @brief Launches the <tt>apt-get update</tt> command. */
-	void onAptUpdate();
-	/** @brief Reloads the package database. */
-	void onReloadDb();
 	/** @brief This function will be called if the update finished. 
 	  *
 	  * It will update the database used. 
