@@ -13,10 +13,19 @@
 #ifndef __INSTALLATIONTOOL_20080605
 #define __INSTALLATIONTOOL_20080605
 
+namespace NApt 
+{
+
 enum InstallationTool {
 	APT,
 	APTITUDE
 };
 
+
+/** @brief Returns the command to execute the given installation tool (e.g. /usr/bin/apt). */
+QString getInstallationToolCommand(InstallationTool tool) ;
+
+} // namespace NApt
+
 #endif // __INSTALLATIONTOOL_20080605
 
