@@ -23,8 +23,6 @@
 
 #include "debtagsplugin.h"
 
-#include <ept/debtags/debtags.h>
-
 // NUtil
 #include "debtagshelper.h"
 
@@ -37,7 +35,7 @@
 #include "vocabularymodel.h"
 
 typedef std::string Package;
-typedef ept::debtags::Tag Tag;
+typedef std::string Tag;
 
 using namespace std;
 
@@ -85,8 +83,6 @@ void DebtagsPlugin::init(IProvider* pProvider)
 	connect(vocabularyModel(), SIGNAL(dataChanged(const QModelIndex&, const QModelIndex&)), SLOT(onTagSelectionChanged()));
 	connect(vocabularyModel(), SIGNAL(modelReset()), SLOT(onTagSelectionChanged()));
 	
-	if ( _container.collection()==0 )
-		setWidgetsEnabled(false);
 }
 
 
@@ -138,10 +134,7 @@ void DebtagsPlugin::clearSearch()
 QString DebtagsPlugin::informationText(const string& package)
 {
 	{	// add the tags of the package to the description
-		Package packageEntity= NUtil::getPackageByName(package, _pProvider->apt());
-		if (packageEntity.empty())
-			throw NPlugin::PackageNotFoundException(package);
-		set<string> tagset = NUtil::tagsToStrings(_container.collection()->getTagsOfItem(packageEntity));
+		set<string> tagset = NUtil::tagsForPackage(package, _pProvider->xapian());
 		if (tagset.empty()) return _emptyString;
 		QString detailsString = "<b>Tags:</b> ";
 		for (set<string>::iterator it = tagset.begin(); ; )
@@ -170,74 +163,38 @@ void DebtagsPlugin::showExcludeWidgets(bool )
 }
 
 
-/** This creates a search expression which can be used as input for an ExpressionFiler.
-  * @returns the filter string
-  */
-std::string DebtagsPlugin::createSearchExpression()
-{
-	ostringstream oexpr;
-	// the list view that displays the selected tags
-	set<Tag> includeTags = vocabularyModel()->selectedTags();
-	bool first = true;
-	for (set<Tag>::const_iterator it = includeTags.begin(); it != includeTags.end(); ++it)
-	{
-		if (!first)
-			oexpr << " && ";
-		else 
-			first = false;
-
-		oexpr << it->fullname();
-	}
-	// the list view that displays the selected tags
-// 	set<Tag> excludeTags = fill in here;
-// 	for (set<Tag>::const_iterator it = excludeTags.begin(); it != excludeTags.end(); ++it)
-// 	{
-// 		if (!first)
-// 		{
-// 			first = false;
-// 			oexpr << " && ";
-// 		}
-// 		oexpr << "!" << it->fullname();
-// 	}
-	return oexpr.str();	
-}
-
-
 void DebtagsPlugin::evaluateSearch()
 {
 	_pProvider->reportBusy(this, tr("Performing tag search on package database"));
 //	statusBar()->message(tr("Searching Package Database for tags"));
 	_searchResult.clear();
-	string expression = createSearchExpression();
-	qStrDebug("searching for " + toQString(expression));
-	if (expression.empty())	// if nothing is selected, do not show anything
+	set<Tag> includeTags = vocabularyModel()->selectedTags();
+	if (includeTags.empty())	// if nothing is selected, do not show anything
 	{
 		_isInactive = true;
 	}
 	else
 	{
 		_isInactive = false;
- 		_searchResult = NUtil::packagesToStrings( _container.collection()->getItemsHavingTags(
- 			vocabularyModel()->selectedTags()) );
+		
+		Xapian::Enquire enq(_pProvider->xapian());
+		set<string> terms;		
+		for (set<Tag>::const_iterator it = includeTags.begin(); it != includeTags.end(); ++it)
+		{
+			terms.insert(string("XT")+*it);
+		}
+
+		Xapian::Query query(Xapian::Query::OP_AND, terms.begin(), terms.end());
+		enq.set_query(query);
+		Xapian::MSet match = enq.get_mset(0, 500000);
+ 		for (Xapian::MSet::const_iterator it = match.begin(); it != match.end(); ++it)
+ 			_searchResult.insert( it.get_document().get_data());
 	}
 	_pProvider->reportReady(this);
 	emit searchChanged(this);
 }
 
 
-void DebtagsPlugin::debtagsDataChanged()
-{
-	clearSearch();
-	if (_container.collection()==0)
-		setWidgetsEnabled(false);
-	else
-	{
-// 		_pIncludeSelection->loadVocabulary(_container.facets());
-		setWidgetsEnabled(true);
-	}
-//	clearSearch();
-}
-
 void DebtagsPlugin::setWidgetsEnabled(bool enabled)
 {
 	_pTagSelection->setEnabled(enabled);
@@ -261,9 +218,4 @@ NTagModel::VocabularyModel* DebtagsPlugin::vocabularyModel()
 }	// namespace NPlugin
 
 #undef emit
-/*
-#include <ept/cache/apt/packages.tcc>
-#include <ept/cache/debtags/vocabulary.tcc>
-#include <ept/cache/tag.tcc>
-#include <tagcoll/coll/base.tcc>
-*/
+
