@@ -9,8 +9,9 @@
 #include <sys/types.h>	//
 
 #include <wibble/operators.h>
-#include <ept/debtags/debtags.h>
-#include <ept/debtags/tag.h>
+
+#include <xapian.h>
+
 
 #include "debtagsplugincontainer.h"
 
@@ -102,22 +103,54 @@ DebtagsPluginContainer::~DebtagsPluginContainer()
 bool DebtagsPluginContainer::init(IProvider* pProvider)
 {
 	BasePluginContainer::init(pProvider, DebtagsPluginFactory::getInstance());
-	updateDebtags();
+	
+
+	NUtil::IProgressObserver* pProgressObserver = provider()->progressObserver();
+	if (pProgressObserver)
+		pProgressObserver->setText("Loading Debtags Plugin");
+	if (!_vocabulary.hasData())
+	{
+		setDebtagsEnabled(false);	// disable the debtags system
+		provider()->reportError(
+			tr("No vocabulary available" ),
+			tr(
+				"<p>The vocabulary is not available. This should not happen. Please reinstall "
+				"<tt>debtags</tt> or check your /var/lib/debtags/vocabulary file manually.</p>"
+				"The debtags plugin will be disabled for now, you can re-enable it via the Packagesearch menu -> Control Plugins."
+				"</p>")
+/*				"<p>"
+				"The original error message reported by debtags was:<br>"
+				"<tt>"
+			) +
+			toQString(e.desc()) +
+			"</tt>"
+			"</p>"*/
+		);
+		return false;
+	}
+
+	setDebtagsEnabled(true);
+
 	_pVocabularyModel = new NTagModel::VocabularyModel(this);
 
 #ifdef __DEBUG
 	new ModelTest(_pVocabularyModel, this);
 #endif
 	
-	if (debtagsEnabled())
-	{
-		// use dynamic cast here because of the virtual base class 
-		// (static_cast is not allowed there)
-		_pRelatedPlugin = dynamic_cast<RelatedPlugin*>(requestPlugin("RelatedPlugin"));
-		_pDebtagsPlugin = dynamic_cast<DebtagsPlugin*>(requestPlugin("DebtagsPlugin"));
-	}
+	// use dynamic cast here because of the virtual base class 
+	// (static_cast is not allowed there)
+	_pRelatedPlugin = dynamic_cast<RelatedPlugin*>(requestPlugin("RelatedPlugin"));
+	_pDebtagsPlugin = dynamic_cast<DebtagsPlugin*>(requestPlugin("DebtagsPlugin"));
 	
-	return debtagsEnabled();
+	// inform the plugins about the new collections
+/*	if (_pDebtagsPlugin)
+		_pDebtagsPlugin->debtagsDataChanged();
+	if (_pRelatedPlugin)
+		_pRelatedPlugin->debtagsDataChanged();
+	if (pProgressObserver)
+		pProgressObserver->setProgress(100);*/
+	
+	return true;
 }
 
 vector< pair<QString, QAction*> > DebtagsPluginContainer::actions()
@@ -157,22 +190,20 @@ QDomElement DebtagsPluginContainer::loadContainerSettings(const QDomElement sour
 		string hiddenFacet = toString( hiddenFacets.item(i).toElement().text() );
 		_pVocabularyModel->setFacetHidden(true, hiddenFacet);
 	}
-	if (debtagsEnabled())
-		updateVocabulary();
 	return NXml::getNextElement(source);
 }
 
 void DebtagsPluginContainer::saveContainerSettings(NXml::XmlData& outData, QDomElement parent) const
 {
 	qDebug("saveContainerSettings called");
-	typedef ept::debtags::Facet Facet;
+	typedef std::string Facet;
 	QDomElement containerElement = outData.addElement(parent, "ContainerSettings");
 	outData.addAttribute(containerElement, 0.1f, "settingsVersion");
 	set<Facet> hiddenFacets = _pVocabularyModel->hiddenFacets();
 	for (set<Facet>::const_iterator it = hiddenFacets.begin(); it != hiddenFacets.end(); ++it)
 	{
 		QDomElement hiddenFacetElement = outData.addElement(containerElement, "HiddenFacet");
-		outData.addText(hiddenFacetElement, it->name());
+		outData.addText(hiddenFacetElement, *it);
 	}
 }
 
@@ -184,83 +215,9 @@ void DebtagsPluginContainer::saveContainerSettings(NXml::XmlData& outData, QDomE
 // Helper Methods
 /////////////////////////////////////////////////////
 
-void DebtagsPluginContainer::updateVocabulary(bool informPlugins)
+const Xapian::Database& DebtagsPluginContainer::xapian() const
 {
-	if (informPlugins)
-	{
-		if (_pDebtagsPlugin)
-			_pDebtagsPlugin->debtagsDataChanged();
-		if (_pRelatedPlugin)
-			_pRelatedPlugin->debtagsDataChanged();
-	}
-}
-
-void DebtagsPluginContainer::updateDebtags()
-{
-	NUtil::IProgressObserver* pProgressObserver = provider()->progressObserver();
-	if (pProgressObserver)
-		pProgressObserver->setText("Loading Debtags Plugin");
-/*	try 
-	{
-		// this is set to 0 if no listener is available
-		cache::Global::get().close();
-		qDebug("Opening aptfront cache for debtags");
-		cache::Global::get().open(cache::Cache::OpenDefault
-				| cache::Cache::OpenReadOnly
-				| cache::Cache::OpenTags
-				| cache::Cache::OpenDebtags);
-	}
-	catch (Tagcoll::SystemException e)*/
-	
-	if (!collection()->hasData())
-	{
-		setDebtagsEnabled(false);	// disable the debtags system
-		provider()->reportError(
-			tr("Tag Database Not Available" ),
-			tr(
-				"<p>The tag database is not available and the debtags plugin was disabled!</p>"
-				"<p>"
-				"You must execute <tt><b>debtags update</b></tt> as root on the commandline to download "
-				"the database. If debtags is not on your system you can install it via "
-				"<tt><b>apt-get install debtags</b></tt><br>"
-				"Afterwards you can enable the debtags plugin via the Packagesearch menu -> Control Plugins."
-				"</p>")
-/*				"<p>"
-				"The original error message reported by debtags was:<br>"
-				"<tt>"
-			) +
-			toQString(e.desc()) +
-			"</tt>"
-			"</p>"*/
-		);
-		return;
-	}
-/*	catch (exception::Error e)
-	{
-		setDebtagsEnabled(false);	// disable the debtags system
-		provider()->reportError(
-			tr("Unknown Error when reading the Debtags database" ),
-			tr("An unknown error occured when reading the debtags database.<br>"
-				"The error reported by debtags is:.<br><tt>") +
-			toQString(e.what()) +
-			"</tt>"
-		);
-		return;
-	}*/
-
-	setDebtagsEnabled(true);
-	if (debtagsEnabled())
-	{
-		// load the new vocabulary
-		updateVocabulary(false);
-	}
-	// inform the plugins about the new collections
-	if (_pDebtagsPlugin)
-		_pDebtagsPlugin->debtagsDataChanged();
-	if (_pRelatedPlugin)
-		_pRelatedPlugin->debtagsDataChanged();
-	if (pProgressObserver)
-		pProgressObserver->setProgress(100);
+	return provider()->xapian();
 }
 
 void DebtagsPluginContainer::setDebtagsEnabled(bool enabled)
@@ -268,14 +225,9 @@ void DebtagsPluginContainer::setDebtagsEnabled(bool enabled)
 	_debtagsEnabled = enabled;
 }
 
-const ept::debtags::Debtags* DebtagsPluginContainer::collection() const	
-{
-	return &(provider()->debtags());
-}
-
 const std::set<DebtagsPluginContainer::Facet> DebtagsPluginContainer::facets() const
 {
-	const Vocabulary& tags = provider()->debtags().vocabulary();
+	const Vocabulary& tags = provider()->vocabulary();
 	return tags.facets(); 
 }
 
