@@ -1,23 +1,12 @@
 #ifndef __RELATEDPLUGIN_H_2004_06_23
 #define __RELATEDPLUGIN_H_2004_06_23
 
-#if 0
-#include <tagcoll/OpSet.h>
-#include <tagcoll/CardinalityStore.h>
-#include <tagcoll/InputMerger.h>
-#endif
-
 
 // NPlugin
 #include <searchplugin.h>
 #include <scoreplugin.h>
 #include <debtagsplugincontainer.h>
-
-namespace ept {
-namespace debtags {
-class Tag;
-}
-}
+#include <scorecalculationstrategybase.h>
 
 class QMainWindow;
 
@@ -41,9 +30,22 @@ namespace NPlugin
 class RelatedPlugin : public SearchPlugin, public ScorePlugin
 {
 	Q_OBJECT
+	
+	/** Class used to calculate the scores for related plugins. */
+	class ScoreCalculator : public ScoreCalculationStrategyBase {
+	public:
+		/** @brief Holds the scores for the packages in the search result. */
+		map<string, float> _scores;
+		/** @brief Calculates the scores for the handed set of packages.
+		*
+		* Old calculations will be cleared.
+		*/
+		virtual void calculateScore(const set<string>& packages);
+	};
+	
+	
 
-	typedef std::string Package;
-	typedef ept::debtags::Tag Tag;
+	typedef std::string Tag;
 public:
 	static const QString PLUGIN_NAME;
 	RelatedPlugin(const DebtagsPluginContainer& container);
@@ -101,11 +103,9 @@ public:
 	virtual bool offersScore() const;
 	//@}
 
-	/** @brief This can be used to notify the plugin that the debtags data in the 
-	  * plugin container (i.e. the tag collection and the vocabulary) has changed. 
-	  *
-	  * If the tag collection is 0 the plugin will disable itself. */
-	void debtagsDataChanged();
+
+
+
 protected slots:
 	/** @brief Called whenever the user requests to clear the search. */
 	void onClearSearch()	{ clearSearch(); };
@@ -123,6 +123,8 @@ protected slots:
 	/** This enables/ disables the visible widgets. */
 	void setWidgetsEnabled(bool enabled);
 private:
+	/** Used to calculate the scores fo the plugin. */
+	mutable ScoreCalculator _calculator;
 	/** The container which holds this plugin. */
 	const DebtagsPluginContainer& _container;
 	/** @brief Holds the result of the search currently active. */
