@@ -11,6 +11,7 @@
 //
 #include "scorecalculationstrategybase.h"
 
+
 namespace NPlugin {
 
 ScoreCalculationStrategyBase::ScoreCalculationStrategyBase()
@@ -28,12 +29,17 @@ ScoreCalculationStrategyBase::~ScoreCalculationStrategyBase()
 /////////////////////////////////////////////////////
 
 
-float ScoreCalculationStrategyBase::getScore(const string& package)
+float ScoreCalculationStrategyBase::getScore(const string& package) const
 {
-	return _packagesToScore[package];
+	map<string, float>::const_iterator it = _packagesToScore.find(package);
+	if (it == _packagesToScore.end()) {
+		qWarning("No scores for package %s", package.c_str());
+		return 1;
+	}
+	return it->second;
 }
 
-const map<string, float>& ScoreCalculationStrategyBase::getScore()
+const map<string, float>& ScoreCalculationStrategyBase::getScore() const
 {
 	return _packagesToScore;
 }
