@@ -36,6 +36,7 @@ class ScorePlugin;
   */
 class ScoreDisplayPlugin : public ShortInformationPlugin, public IPluginUser
 {
+Q_OBJECT
 	const QString _title;
 	const QString _briefDescription;
 	const QString _description;
@@ -73,7 +74,7 @@ public:
 	virtual uint shortInformationPriority() const	{ return 0; }
 	virtual const QString shortInformationText(const string& package);
 	/** @brief Returns <b>Score</b> */
-	virtual QString shortInformationCaption() const { return QString("Score"); };
+	virtual QString shortInformationCaption() const { return tr("Score"); };
 	virtual int preferredColumnWidth() const { return 5; }
 	//@}
 	/** @brief Called whenever the scores of the package have changed.
