@@ -1,74 +1,69 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="de">
-<defaultcodec></defaultcodec>
+<!DOCTYPE TS>
+<TS version="2.0" language="de">
 <context>
     <name>AptSearchPluginShortInputWidget</name>
     <message>
-        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="13"/>
+        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="14"/>
         <source>Form1</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="25"/>
+        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="26"/>
         <source>Search for pattern</source>
         <translation>Nach Zeichenkette suchen</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="40"/>
+        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="41"/>
         <source>Search the package database for the given expression</source>
         <translation>Durchsucht die Paketdatenbank nach dem angegebenen Ausdruck</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="51"/>
+        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="52"/>
         <source>Clear</source>
         <translation>Löschen</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="65"/>
         <source>Search case sensitive</source>
-        <translation>Groß-/Kleinschreibung beachten</translation>
+        <translation type="obsolete">Groß-/Kleinschreibung beachten</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="68"/>
         <source>Case Sensitive</source>
-        <translation>Groß-/Kleinschreibung</translation>
+        <translation type="obsolete">Groß-/Kleinschreibung</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="75"/>
+        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="66"/>
         <source>Search the package descriptions</source>
         <translation>Paketbeschreibungen mit durchsuchen</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="81"/>
+        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="72"/>
         <source>Search Descriptions</source>
         <translation>Beschreibungen durchsuchen</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="91"/>
         <source>Search only full words matching the search patterns</source>
-        <translation>Nur ganze Wörter suchen die dem Suchausdruck entsprechen, keine Teilausdrücke</translation>
+        <translation type="obsolete">Nur ganze Wörter suchen die dem Suchausdruck entsprechen, keine Teilausdrücke</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="94"/>
         <source>When searching only full word matches of the pattern will be considered a match, i.e. if a part of a word matches the pattern it will not be considered a match.
 Every non-alphanumeric character is considerd to be a word boundary.</source>
-        <translation>Es wird nur nach ganzen Wörtern gesucht, die dem Suchausdruck entsprechen.
+        <translation type="obsolete">Es wird nur nach ganzen Wörtern gesucht, die dem Suchausdruck entsprechen.
 Jedes nicht-alphanumerische Zeichen wird dabei als Wortgrenze betrachtet.</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="98"/>
         <source>Whole Words Only</source>
-        <translation>Ganze Wörter</translation>
+        <translation type="obsolete">Ganze Wörter</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="43"/>
+        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="44"/>
         <source>This searches the package names and descriptions for the given pattern. If you enter more than one word all words must be contained.&lt;br&gt;
 You can search for phrases by using double quotes around the phrase. To enter patterns or phrases which should not appear in the package precede them with a minus (&apos;-&apos;).</source>
         <translation>Die Paketnamen und -beschreibungen werden nach der eingegebenen Zeichenkette durchsucht. Wird mehr als ein Wort angeben, so müssen alle Wörter gefunden werden.&lt;br&gt;
 Nach Wortgruppen kann gesucht werden, indem diese in Anführungsstriche gesetzt werden. Um eine unerwünschte Zeichenkette einzugeben kann ein Minuszeichen &apos;-&apos; vorangestellt werden.</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="78"/>
+        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="69"/>
         <source>Check this if you want to search in the package descriptions. The search will search the package name, the long description and the short description.&lt;br /&gt;If not checked only the package names will be searched.</source>
         <translation>Wenn dieses Kästchen aktiviert ist, werden die Paketbeschreibungen mit durchsucht. Die Suche sucht dann in dem Namen, der ausführlichen und der Kurzbeschreibung. Ansonsten werden nur die Paketnamen durchsucht.</translation>
     </message>
@@ -152,62 +147,70 @@ Nach Wortgruppen kann gesucht werden, indem diese in Anführungsstriche gesetzt
 <context>
     <name>NPlugin::AptActionPlugin</name>
     <message>
-        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="39"/>
+        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="42"/>
         <source>Update Apt-Package Database</source>
         <translation>Apt-Paketdatenbank aktualisieren</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="40"/>
         <source>Calls &quot;apt-get update&quot; updating the package database</source>
-        <translation>Ruft &quot;apt-get update&quot; bzw. &quot;aptitude update&quot; zum aktualisieren der Paketdatenbank auf</translation>
+        <translation type="obsolete">Ruft &quot;apt-get update&quot; bzw. &quot;aptitude update&quot; zum aktualisieren der Paketdatenbank auf</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="44"/>
+        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="43"/>
+        <source>Updates the package database</source>
+        <translation>Paketdatenbank aktualisieren</translation>
+    </message>
+    <message>
+        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="48"/>
         <source>Reloads the package database from disk (e.g. if apt-get update was performed externally).</source>
         <translation>Aktualisiert die Paketinformationen von der Festplatte (z.B. wenn &quot;aptitude update&quot; extern aufgerufen wurde).</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="48"/>
+        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="54"/>
         <source>Copy Command Line for Installing Package to Clipboard</source>
         <translation>Kommandozeile zur Paketinstallation in Zwischenablage kopieren</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="50"/>
+        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="55"/>
+        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="56"/>
         <source>Creates a command line to install the selected package, and copies it to the clipboard</source>
         <translation>Erzeugt Kommandozeile zur Installation des Paketes und kopiert diese in die Zwischenablage</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="54"/>
+        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="60"/>
         <source>Install/Update Package</source>
         <translation>Paket Installieren/Aktualisieren</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="56"/>
+        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="61"/>
+        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="62"/>
         <source>Installs/updates the package</source>
         <translation>Installiert/aktualisiert das Paket</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="60"/>
+        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="66"/>
         <source>Remove Package</source>
         <translation>Paket entfernen</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="62"/>
+        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="67"/>
+        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="68"/>
         <source>Removes the package</source>
         <translation>Entfernt das Paket</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="66"/>
+        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="72"/>
         <source>Purge Package</source>
         <translation>Paket restlos entfernen</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="68"/>
+        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="73"/>
+        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="74"/>
         <source>Removes package including configuration</source>
         <translation>Entfernt Paket inklusive der Konfigurationsdateien</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="169"/>
+        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="183"/>
         <source>Unable to launch command</source>
         <translation>Konnte Programm nicht starten</translation>
     </message>
@@ -215,12 +218,13 @@ Nach Wortgruppen kann gesucht werden, indem diese in Anführungsstriche gesetzt
 <context>
     <name>NPlugin::AptPluginContainer</name>
     <message>
-        <location filename="../src/plugins/aptplugin/aptplugincontainer.cpp" line="203"/>
+        <location filename="../src/plugins/aptplugin/aptplugincontainer.cpp" line="199"/>
+        <location filename="../src/plugins/aptplugin/aptplugincontainer.cpp" line="208"/>
         <source>Command not executed</source>
         <translation>Programm nicht ausgeführt</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptplugincontainer.cpp" line="195"/>
+        <location filename="../src/plugins/aptplugin/aptplugincontainer.cpp" line="199"/>
         <source>For an unknwon reason, the command could not be executed.</source>
         <translation>Aufgrund eines unbekannten Fehlers konnte das Programm nicht ausgeführt werden.</translation>
     </message>
@@ -243,12 +247,12 @@ Nach Wortgruppen kann gesucht werden, indem diese in Anführungsstriche gesetzt
         <translation>Dieser Plugin kann verwendet werden, um Pakete nach bestimmten Ausdrücken zu durchsuchen.</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptsearchplugin.cpp" line="148"/>
+        <location filename="../src/plugins/aptplugin/aptsearchplugin.cpp" line="137"/>
         <source>Delayed evaluation - waiting for further input</source>
         <translation>Verzögerte Auswertung - warte auf weitere Eingaben</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptsearchplugin.cpp" line="158"/>
+        <location filename="../src/plugins/aptplugin/aptsearchplugin.cpp" line="147"/>
         <source>Performing full text search on package database</source>
         <translation>Volltextsuche über Paketdatenbank wird ausgeführt</translation>
     </message>
@@ -261,6 +265,7 @@ Nach Wortgruppen kann gesucht werden, indem diese in Anführungsstriche gesetzt
         <translation>Plugin für Verfügbare Version</translation>
     </message>
     <message>
+        <location filename="../src/plugins/aptplugin/availableversionplugin.cpp" line="28"/>
         <location filename="../src/plugins/aptplugin/availableversionplugin.cpp" line="29"/>
         <source>Shows the version for the package available for download</source>
         <translation>Zeigt Informationen über die verfügbare Version von Paketen an</translation>
@@ -279,6 +284,7 @@ Nach Wortgruppen kann gesucht werden, indem diese in Anführungsstriche gesetzt
         <translation>Plugin für Installierte Version</translation>
     </message>
     <message>
+        <location filename="../src/plugins/aptplugin/installedversionplugin.cpp" line="26"/>
         <location filename="../src/plugins/aptplugin/installedversionplugin.cpp" line="27"/>
         <source>Shows the version of the installed package in the package list</source>
         <translation>Zeigt Informationen über die installierte Version von Paketen an</translation>
@@ -292,17 +298,17 @@ Nach Wortgruppen kann gesucht werden, indem diese in Anführungsstriche gesetzt
 <context>
     <name>NPlugin::PackageDescriptionPlugin</name>
     <message>
+        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="63"/>
         <location filename="../src/plugins/aptplugin/packagedescriptionplugin.h" line="91"/>
         <source>Description</source>
         <translation>Beschreibung</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="190"/>
+        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="189"/>
         <source>&lt;h3&gt;Package not found&lt;/h3&gt;&lt;p&gt;Could not find a valid description for the package &lt;b&gt;</source>
         <translation>&lt;h3&gt;Paket nicht gefunden&lt;/h3&gt;&lt;p&gt;Für das Paket &lt;b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="195"/>
         <source>&lt;/b&gt; in the database.&lt;br&gt;This could mean either that you have selected a virtual package or that the package description  was not found for an unknown reason. It is possible that your debtags and apt database are out of sync. Try running &lt;tt&gt;debtags update&lt;/tt&gt; and &lt;tt&gt;apt-get update&lt;/tt&gt; as root.&lt;/p&gt;</source>
         <translation type="obsolete"> konnte keine gültige Beschreibung in der Datenbank gefunden werden. &lt;br&gt;Dies bedeutet entweder dass ein virtuelles Paket ausgewählt wurde oder dass die Paketbeschreibung aus einem anderen Grund nicht gefunden werden konnte. &lt;/p&gt;</translation>
     </message>
@@ -312,7 +318,7 @@ Nach Wortgruppen kann gesucht werden, indem diese in Anführungsstriche gesetzt
         <translation>Plugin für Paketbeschreibungen</translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="193"/>
+        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="191"/>
         <source>&lt;/b&gt; in the database.&lt;br&gt;This could mean either that you have selected a virtual package or that the package description  was not found for an unknown reason.&lt;/p&gt;</source>
         <translation> konnte keine gültige Beschreibung in der Datenbank gefunden werden. &lt;br&gt;Dies bedeutet entweder dass ein virtuelles Paket ausgewählt wurde oder dass die Paketbeschreibung aus einem anderen Grund nicht gefunden werden konnte. &lt;/p&gt;</translation>
     </message>
@@ -469,7 +475,7 @@ Nach Wortgruppen kann gesucht werden, indem diese in Anführungsstriche gesetzt
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="42"/>
+        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="47"/>
         <source>Reload Package Database</source>
         <translation>Neuladen der Paketdatenbank</translation>
     </message>
