@@ -1,74 +1,49 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1">
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>AptSearchPluginShortInputWidget</name>
     <message>
-        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="13"/>
+        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="14"/>
         <source>Form1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="25"/>
+        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="26"/>
         <source>Search for pattern</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="40"/>
+        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="41"/>
         <source>Search the package database for the given expression</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="43"/>
+        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="44"/>
         <source>This searches the package names and descriptions for the given pattern. If you enter more than one word all words must be contained.&lt;br&gt;
 You can search for phrases by using double quotes around the phrase. To enter patterns or phrases which should not appear in the package precede them with a minus (&apos;-&apos;).</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="51"/>
+        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="52"/>
         <source>Clear</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="65"/>
-        <source>Search case sensitive</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="68"/>
-        <source>Case Sensitive</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="75"/>
+        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="66"/>
         <source>Search the package descriptions</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="78"/>
+        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="69"/>
         <source>Check this if you want to search in the package descriptions. The search will search the package name, the long description and the short description.&lt;br /&gt;If not checked only the package names will be searched.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="81"/>
+        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="72"/>
         <source>Search Descriptions</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="91"/>
-        <source>Search only full words matching the search patterns</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="94"/>
-        <source>When searching only full word matches of the pattern will be considered a match, i.e. if a part of a word matches the pattern it will not be considered a match.
-Every non-alphanumeric character is considerd to be a word boundary.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="98"/>
-        <source>Whole Words Only</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>AptSettingsWidget</name>
@@ -149,62 +124,66 @@ Every non-alphanumeric character is considerd to be a word boundary.</source>
 <context>
     <name>NPlugin::AptActionPlugin</name>
     <message>
-        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="39"/>
+        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="42"/>
         <source>Update Apt-Package Database</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="40"/>
-        <source>Calls &quot;apt-get update&quot; updating the package database</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="44"/>
-        <source>Reloads the package database from disk (e.g. if apt-get update was performed externally).</source>
+        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="43"/>
+        <source>Updates the package database</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="48"/>
-        <source>Copy Command Line for Installing Package to Clipboard</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="50"/>
-        <source>Creates a command line to install the selected package, and copies it to the clipboard</source>
+        <source>Reloads the package database from disk (e.g. if apt-get update was performed externally).</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="54"/>
-        <source>Install/Update Package</source>
+        <source>Copy Command Line for Installing Package to Clipboard</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="55"/>
         <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="56"/>
-        <source>Installs/updates the package</source>
+        <source>Creates a command line to install the selected package, and copies it to the clipboard</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="60"/>
-        <source>Remove Package</source>
+        <source>Install/Update Package</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="61"/>
         <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="62"/>
-        <source>Removes the package</source>
+        <source>Installs/updates the package</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="66"/>
+        <source>Remove Package</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="67"/>
+        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="68"/>
+        <source>Removes the package</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="72"/>
         <source>Purge Package</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="68"/>
+        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="73"/>
+        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="74"/>
         <source>Removes package including configuration</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="169"/>
+        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="183"/>
         <source>Unable to launch command</source>
         <translation type="unfinished"></translation>
     </message>
@@ -212,12 +191,13 @@ Every non-alphanumeric character is considerd to be a word boundary.</source>
 <context>
     <name>NPlugin::AptPluginContainer</name>
     <message>
-        <location filename="../src/plugins/aptplugin/aptplugincontainer.cpp" line="203"/>
+        <location filename="../src/plugins/aptplugin/aptplugincontainer.cpp" line="199"/>
+        <location filename="../src/plugins/aptplugin/aptplugincontainer.cpp" line="208"/>
         <source>Command not executed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptplugincontainer.cpp" line="195"/>
+        <location filename="../src/plugins/aptplugin/aptplugincontainer.cpp" line="199"/>
         <source>For an unknwon reason, the command could not be executed.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -240,12 +220,12 @@ Every non-alphanumeric character is considerd to be a word boundary.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptsearchplugin.cpp" line="148"/>
+        <location filename="../src/plugins/aptplugin/aptsearchplugin.cpp" line="137"/>
         <source>Delayed evaluation - waiting for further input</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/aptsearchplugin.cpp" line="158"/>
+        <location filename="../src/plugins/aptplugin/aptsearchplugin.cpp" line="147"/>
         <source>Performing full text search on package database</source>
         <translation type="unfinished"></translation>
     </message>
@@ -258,6 +238,7 @@ Every non-alphanumeric character is considerd to be a word boundary.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../src/plugins/aptplugin/availableversionplugin.cpp" line="28"/>
         <location filename="../src/plugins/aptplugin/availableversionplugin.cpp" line="29"/>
         <source>Shows the version for the package available for download</source>
         <translation type="unfinished"></translation>
@@ -276,6 +257,7 @@ Every non-alphanumeric character is considerd to be a word boundary.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../src/plugins/aptplugin/installedversionplugin.cpp" line="26"/>
         <location filename="../src/plugins/aptplugin/installedversionplugin.cpp" line="27"/>
         <source>Shows the version of the installed package in the package list</source>
         <translation type="unfinished"></translation>
@@ -289,17 +271,18 @@ Every non-alphanumeric character is considerd to be a word boundary.</source>
 <context>
     <name>NPlugin::PackageDescriptionPlugin</name>
     <message>
+        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="63"/>
         <location filename="../src/plugins/aptplugin/packagedescriptionplugin.h" line="91"/>
         <source>Description</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="190"/>
+        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="189"/>
         <source>&lt;h3&gt;Package not found&lt;/h3&gt;&lt;p&gt;Could not find a valid description for the package &lt;b&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="193"/>
+        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="191"/>
         <source>&lt;/b&gt; in the database.&lt;br&gt;This could mean either that you have selected a virtual package or that the package description  was not found for an unknown reason.&lt;/p&gt;</source>
         <translation type="unfinished"></translation>
     </message>
@@ -460,13 +443,13 @@ Every non-alphanumeric character is considerd to be a word boundary.</source>
     <message>
         <location filename="../src/plugins/aptplugin/packagestatusplugin.cpp" line="22"/>
         <source></source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="42"/>
+        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="47"/>
         <source>Reload Package Database</source>
         <translation type="unfinished"></translation>
     </message>
