@@ -1,5 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1">
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>ColumnControlDlg</name>
     <message>
@@ -51,10 +52,10 @@
 <context>
     <name>MainProgram</name>
     <message>
-        <location filename="../src/main.cpp" line="72"/>
+        <location filename="../src/main.cpp" line="69"/>
         <source>Usage: packagesearch [options]
-<byte value="x9"/>-h, --help     prints this message
-<byte value="x9"/>-v, --version  prints the version information
+	-h, --help     prints this message
+	-v, --version  prints the version information
 If started without options the UI is launched
 </source>
         <translation type="unfinished"></translation>
@@ -91,12 +92,13 @@ If started without options the UI is launched
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../src/packagenameplugin.cpp" line="24"/>
         <location filename="../src/packagenameplugin.cpp" line="25"/>
         <source>Displays the package names</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/packagenameplugin.h" line="62"/>
+        <location filename="../src/packagenameplugin.h" line="63"/>
         <source>Name</source>
         <translation type="unfinished"></translation>
     </message>
@@ -127,7 +129,7 @@ If started without options the UI is launched
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/scoredisplayplugin.cpp" line="33"/>
+        <location filename="../src/scoredisplayplugin.cpp" line="32"/>
         <source>Displays the search scores of the packages returned by the current search.&lt;br&gt;
 The higher the scores, the better the packages matches to the search.</source>
         <translation type="unfinished"></translation>
@@ -241,11 +243,13 @@ The higher the scores, the better the packages matches to the search.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../src/packagesearch.ui" line="486"/>
         <location filename="../src/packagesearch.ui" line="489"/>
         <source>Exit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../src/packagesearch.ui" line="494"/>
         <location filename="../src/packagesearch.ui" line="497"/>
         <source>Control Plugins</source>
         <translation type="unfinished"></translation>
@@ -339,32 +343,53 @@ p, li { white-space: pre-wrap; }
 <context>
     <name>PackageSearchImpl</name>
     <message>
-        <location filename="../src/packagesearchimpl.cpp" line="218"/>
+        <location filename="../src/packagesearchimpl.cpp" line="121"/>
+        <source>Displays the packages matching the search entered above.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/packagesearchimpl.cpp" line="220"/>
         <source>Main Toolbar</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/packagesearchimpl.cpp" line="307"/>
+        <location filename="../src/packagesearchimpl.cpp" line="261"/>
+        <source>Error trying to open Xapian database</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/packagesearchimpl.cpp" line="262"/>
+        <source>&lt;p&gt;An error occurred trying to open the xapian database at /var/lib/apt-xapian-index/index please make sure the file is readable and valid. You may try to run update-apt-xapian-index to fix this problem. The orginal error message was:&lt;br&gt;&quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/packagesearchimpl.cpp" line="267"/>
+        <source>Would you like to run update-apt-xapian-index now? Otherwise packagesearch will be terminated.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/packagesearchimpl.cpp" line="337"/>
         <source>Unable to write settings</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/packagesearchimpl.cpp" line="308"/>
+        <location filename="../src/packagesearchimpl.cpp" line="337"/>
         <source>Unable to write settings to</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/packagesearchimpl.cpp" line="679"/>
+        <location filename="../src/packagesearchimpl.cpp" line="693"/>
+        <location filename="../src/packagesearchimpl.cpp" line="705"/>
         <source>Details</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/packagesearchimpl.cpp" line="711"/>
+        <location filename="../src/packagesearchimpl.cpp" line="737"/>
         <source>Evaluating searches</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/packagesearchimpl.cpp" line="956"/>
+        <location filename="../src/packagesearchimpl.cpp" line="982"/>
         <source>Package Search Help Page</source>
         <translation type="unfinished"></translation>
     </message>
